<template>
    <Home>
        <template slot="menu">
            <div class="menu-container">
                <ul>
                    <li v-for="item in navs" :key="item.id" :class="activeId === item.id ? 'active' : ''" @click="goTo(item)">
                        <span>
                            {{ item.label }}
                            <i class="el-icon-caret-bottom" v-show="item.children && item.children.length > 0"></i>
                        </span>
                        <ul v-if="activeId === item.id && showSub">
                            <li v-for="child in item.children" @click="goTo(child)">{{ child.label }}</li>
                        </ul>
                    </li>
                </ul>
                <div class="user">
                    <span>Admin</span>
                    <img @click="logout" src="./logout.png" alt="">
                </div>
            </div>
        </template>
        <template slot="content">
            <router-view></router-view>
        </template>
    </Home>
</template>
<script>
import { mapGetters } from 'vuex'
import Home from '@/components/home/index'
export default {
    components: {
        Home
    },
    data () {
        return {
            navs: [
                {
                    label: '状态监控',
                    pathName: '',
                    id: 1
                },
                {
                    label: '大屏展示',
                    pathName: 'preview',
                    id: 2,
                },
                {
                    label: '车间地图',
                    pathName: '',
                    id: 3,
                    children: [
                        {
                            label: '地图展示',
                            pathName: 'mapPreview'
                        },
                        {
                            label:  '地图编辑',
                            pathName: 'map'
                        }
                    ]
                },
                {
                    label: '车间列表',// workshop
                    id: 4,
                    children: []
                },
                {
                    label: '设备保养',
                    id: 5,
                    children:[
                        {
                            label: '日常保养',
                            pathName:  'maintenance',
                            params: {style: 1},
                            query: {}
                        },
                        {
                            label: '一级保养',
                            pathName:  'maintenance',
                            params: {style: 2},
                            query: {}
                        },
                        {
                            label: '二级保养',
                            pathName:  'maintenance',
                            params: {style: 3},
                            query: {}
                        },
                        {
                            label: '三级保养',
                            pathName:  'maintenance',
                            params: {style: 4},
                            query: {}
                        },
                    ]
                },
                {
                    label: '报表生成',
                    id: 6,
                    children: [
                        {
                            label:  '报表生成1'
                        },
                        {
                            label:  '报表生成1'
                        },
                        {
                            label:  '报表生成1'
                        },
                        {
                            label:  '报表生成1'
                        },
                    ]
                },
                {
                    label: '班次设置',
                    id: 7,
                },
                {
                    label: '工件信息',
                    pathName: 'component',
                    id: 8,
                },
                {
                    label: '更多菜单',
                    id: 9,
                    children: [
                        {
                            label: '台账管理',
                            pathName: 'ledger'
                        },
                        {
                            label: '设备类型',
                            pathName: 'deviceType'
                        },
                        {
                            label: '机床维护',
                            pathName: 'devicemaintenance'
                        }
                    ]
                },
            ],
            activeId: '',
            showSub: false,
        }
    },
    computed: {
        ...mapGetters(['userInfo','workshopList'])
    },
    methods: {
        logout() {
            this.$store.dispatch('LogOut').then(() => {
                // location.reload() // 为了重新实例化vue-router对象 避免bug
                this.$router.push('/')
            })
        },
        goTo (item) {
            if (item.id) {
                if (item.id === this.activeId) {
                    this.showSub = !this.showSub
                } else {
                    this.showSub = true
                }
                this.activeId = item.id || this.activeId
                if(item.pathName) {
                    this.$router.push({name: item.pathName,params: item.params,query: item.query})
                }
            } else {//二级菜单
                this.$router.push({name: item.pathName,params: item.params,query: item.query})
            }
        },
    },
}
</script>
<style lang="scss" scoped>


.menu-container {
    margin-left: auto;
    display: flex;
    line-height: 37px;
    & > ul {
        flex: 0 1 auto;
        color: #AEAFAF;
        font-size: 18px;
        list-style: none;
        display: flex;
        & > li {
            cursor: pointer;
            background: #27394E;
            padding: 0 12px;
            white-space: nowrap;
            text-overflow: ellipsis;
            position: relative;
            ul {
                display: none;
                font-size: 14px;
            }
            // user-select:none;
        }
        & > li.active {
            & > ul {
                padding: 0;
                margin: 0;
                padding-inline: 0;
                list-style: none;
                min-width: 100%;
                display: block;
                position: absolute;
                left: 0;
                z-index: 999;
                background: rgba(0,0,0,.5);
                text-align: center;
                border: 1px solid #0170bc;
                li {
                    padding: 4px;
                    margin: 0;
                    color: #FFF;
                }
                li:hover {
                    color: #68D9FF;
                }
            }
        }
        li~li {
            margin-left: 10px;
        }
        li.active {
            color: #68D9FF;
        }
    }
    .user {
        margin-left: 30px;
        width: 114px;
        height: 37px;
        background: rgba(38, 36, 36, 0.58);
        border-radius: 19px;
        display: flex;
        align-items: center;
        cursor: pointer;
        span {
            padding: 0 13px;
            color: #FFFFFF;
            font-size: 16px;
        }
        img {
            width: 20px;
            height: 20px;
        }
    }
}
</style>